@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,12 +15,14 @@
 #
 
 from .services.container_analysis import ContainerAnalysisClient
+from .services.container_analysis import ContainerAnalysisAsyncClient
+
 from .types.containeranalysis import GetVulnerabilityOccurrencesSummaryRequest
 from .types.containeranalysis import VulnerabilityOccurrencesSummary
 
-
 __all__ = (
+    "ContainerAnalysisAsyncClient",
+    "ContainerAnalysisClient",
     "GetVulnerabilityOccurrencesSummaryRequest",
     "VulnerabilityOccurrencesSummary",
-    "ContainerAnalysisClient",
 )
